dnl -*- m4 -*-
dnl----------------------------------------------------------------------
dnl This is a common set of macros to be used in the configuration of
dnl	the GDS software
dnl----------------------------------------------------------------------

dnl ---------------------------------------------------------------------
 
AC_DEFUN([AC_SENDS_PROG_CC],
[ AC_PROG_CC
if test "${GCC}" = "yes"
then
  touch ,t.c
  ac_dmt_default_cc_includes="`${CC} -v ,t.c 2>&1 | \
        sed -n -e '/\#include/,/End of search list\./p' | \
        egrep '^ '`"
  rm ,t.c
fi
SENDS_CC_FLAVOR="generic"
case $CC in
gcc|*/gcc) SENDS_CC_FLAVOR="gnu";;
cc|*/cc)
    case "`$CC -V 2>&1`" in
    *Sun\ C\ *)
      SENDS_CC_FLAVOR="SunPRO"
      ;;
    esac
    ;;
esac
AM_CONDITIONAL([SENDS_CC_SUNPRO],[test x$SENDS_CC_FLAVOR = xSunPRO])
])
 
dnl ---------------------------------------------------------------------
 
AC_DEFUN([AC_SENDS_PROG_CXX],
[ AC_PROG_CXX
if test "${GXX}" = "yes"
then
  touch ,t.cc
  ac_dmt_default_cxx_includes="`${CXX} -v ,t.cc 2>&1 | \
        sed -n -e '/\#include/,/End of search list\./p' | \
        egrep '^ '`"
  rm ,t.cc
fi
SENDS_CXX_FLAVOR="generic"
case $CXX in
gcc|*/gcc|g++|*/g++) 
    SENDS_CXX_FLAVOR="gnu"
    CXXFLAGS="${CXXFLAGS} -std=c++0x"
    ;;
CC|*/CC)
    case "`$CXX -V 2>&1`" in
    *Sun\ C++*)
      SENDS_CXX_FLAVOR="SunPRO"
      ;;
    esac
    ;;
esac
AC_SYS_LARGEFILE
AM_CONDITIONAL([SENDS_CXX_SUNPRO],[test x$SENDS_CXX_FLAVOR = xSunPRO])
])

dnl======================================================================
dnl AC_SENDS_CHECK_SASL
dnl   Check if SASL is installed
dnl======================================================================

AC_DEFUN([AC_SENDS_CHECK_SASL],
[
have_sasl="no"
sasllibs=
saslcflags=
AC_MSG_CHECKING([for user specified sasl2 library])
AC_ARG_WITH(sasl, 
	    AC_HELP_STRING([--with-sasl@<:@=DIR@:>@],
			   [sasl2 library location @<:@SASL/lib@:>@]
			   ),
	    [have_sasl=yes],
	    [have_sasl=no]
)
AC_MSG_RESULT(${have_sasl})
if test "${have_ssl}" = "yes"
then
    saslcflags="-I${with_sasl}/include -DHAVE_SASL"
    sasllibs="-L${with_sasl}/lib -lsasl2"
    have_sasl=${with_sasl}
else
    AC_CHECK_LIB(sasl2, sasl_client_new, have_sasl="yes", have_ssl="no")
    if test "${have_sasl}" != "no"
    then
        saslcflags=-DHAVE_SASL
        sasllibs=-lsasl2
	have_sasl=sasl2
    else
        AC_CHECK_LIB(sasl, sasl_client_new, have_sasl="yes", have_ssl="no")
        if test "${have_sasl}" = "yes"
        then
            saslcflags=-DHAVE_SASL
            sasllibs=-lsasl
	    have_sasl=${with_sasl}
        fi
    fi
fi
AC_SUBST(sasllibs)
AC_SUBST(saslcflags)
])

dnl======================================================================
dnl SENDS_CHECK_SSL
dnl   Check if OpenSSL is installed
dnl======================================================================

AC_DEFUN([AC_SENDS_CHECK_SSL],
[
found_ssl=no
PKG_CHECK_MODULES(OPENSSL, openssl, found_ssl="yes", found_ssl="no")
if test "${found_ssl}" = "yes"
then
ssllibs="$OPENSSL_LIBS"
sslcflags="$OPENSSL_CFLAGS"
fi
if test "${found_ssl}" = "no"
then
ssllibs=""
sslcflags=""
fi
AM_CONDITIONAL([have_ssl], [ test "x${found_ssl}" = "xyes" ])
AC_SUBST(ssllibs)
AC_SUBST(sslcflags)
])

dnl======================================================================
dnl SENDS_CHECK_GDS
dnl   Check if GDS is installed
dnl======================================================================

AC_DEFUN([AC_SENDS_CHECK_GDS],
[
    have_gds="unspecified"
    have_lsmp="test"
    gdspath=
    gdslibs=
    gdscflags=
    AC_MSG_CHECKING([--with-gds specified])
    AC_ARG_WITH(
	[gds], 
	AC_HELP_STRING([--with-gds@<:@=DIR@:>@], 
		       [dol or dmt package location @<:@from pkgconfig@:>@]
		      ),
    	[have_gds=yes],
	[have_gds=unspecified]
    )
    if test "$have_gds" = "yes"; then
	case "x$with_gds" in
	"xno" | "x")
	    AC_MSG_RESULT([no])
	    have_gds="no"
	    ;;
	*)
	    gdspath="$with_gds"
	    gdslibs="-L$gdspath/lib -lgdsbase -llsmp -lparsl"
	    gdscflags="-I$gdspath/include"
            AC_MSG_RESULT($gdspath)
	    ;;
        esac
    else
        AC_MSG_RESULT([${have_gds}])
    fi
    if test "$have_gds" = "unspecified"; then
        PKG_CHECK_MODULES(GDSLIB, [dol > 2.11], have_gds="yes", have_gds="no")
	if test "${have_gds}" = "yes"; then
	    gdslibs="$GDSLIB_LIBS"
	    gdscflags="$GDSLIB_CFLAGS"
	    gdspath="`pkg-config --libs-only-L dol | sed -e 's,/lib.*$,,g' -e 's,^-L,,g'`"
	fi
    fi
    if test "x$have_gds" = "xno"; then
	gdscflags='-I$(top_srcdir)/src/gdsbits/src'
	gdslibs="../gdsbits/libgdsbits.la"
	gdspath='${prefix}'
	have_lsmp="yes"
    fi

    AC_MSG_CHECKING([for lsmp in $gdspath])
    if test "x$have_lsmp" = "xtest" ; then
	if test -f $gdspath/include/iSMbuf.hh ; then
	    have_lsmp="yes"
	else
	    have_lsmp="no"
	    gdsdefs="-DWITHOUT_LSMP=1"
	fi
    fi
    AC_MSG_RESULT([$have_lsmp])

    AM_CONDITIONAL([build_gds], [ test "x${have_gds}" = "xno" ])
    AM_CONDITIONAL([with_lsmp], [ test "x${have_lsmp}" = "xyes" ])
    AC_SUBST(gdspath)
    AC_SUBST(gdslibs)
    AC_SUBST(gdscflags)
])

dnl======================================================================
dnl SENDS_CHECK_FRAMECPP
dnl   Check if FRAMECPP is installed
dnl======================================================================

AC_DEFUN([AC_SENDS_CHECK_FRAMECPP],
[
    AC_MSG_CHECKING([for --with-framecpp])
    have_framecpp="no"
    framecpplibs=
    framecppcflags=
    AC_ARG_WITH(
	[framecpp],
	AC_HELP_STRING([--with-framecpp@<:@=DIR@:>@], 
		       [framecpp package location @<:@from pkgconfig@:>@]
		      ),
    	[
	    case "x$with_framecpp" in
	    "xno" | "x")
	        have_framecpp="no"
		;;
	    *)
	        have_framecpp="yes"
	        framecpplibs="-L$with_framecpp/lib -lframecpp -lframecppcmn -lgeneral"
		framecppcflags="-I$with_framecpp/include"
		;;
            esac
        ],
	[have_framecpp=no]
    )
    AC_MSG_RESULT($have_framecpp)
    if test "$have_framecpp" = "no" ; then
        PKG_CHECK_MODULES(FRAMECPP, 
		          [framecpp], 
			  [have_framecpp="yes"], 
			  [have_framecpp="no"])
	if test "${have_framecpp}" = "yes" ; then
	    framecpplibs="$FRAMECPP_LIBS -lgeneral"
	    for v in 8 7 6 4 3 cmn; do 
	        framecpplibs="$framecpplibs -lframecpp$v"
	    done
	    framecppcflags="$FRAMECPP_CFLAGS"
	else
	    framecpplibs="-lframecpp -lframecppcmn -lgeneral"
	fi
    fi
    AC_SUBST(framecpplibs)
    AC_SUBST(framecppcflags)
])

dnl======================================================================
dnl SENDS_BUILD_TYPE
dnl   Check build type: online, offline, ...
dnl======================================================================

AC_DEFUN([AC_SENDS_BUILD_TYPE],
[
AC_MSG_CHECKING([for SENDSBUILD])
if test "x$buildtype" = "x"
then
  buildtype=$SENDSBUILD
fi
case "x$buildtype" in
x)
  AC_MSG_RESULT([not specified default: offline])
  buildtype=offline
  ;;
xonline)
  AC_MSG_RESULT([$buildtype])
  ;;
xoffline)
  AC_MSG_RESULT([$buildtype])
  ;;
*)
  AC_MSG_RESULT([$buildtype])
  echo "SENDSBUILD must be specified as online or offline - Aborting"
  exit 1
  ;;
esac

AM_CONDITIONAL([online], [test "$buildtype" = "online"])
AM_CONDITIONAL([offline], [test "$buildtype" = "offline"])
])

dnl======================================================================
dnl SENDS_CHECK_POSIX
dnl	
dnl======================================================================

AC_DEFUN([AC_SENDS_CHECK_POSIX],
[
posixflags="-D_POSIX_C_SOURCE=199506L"
unix98flags="-D_XOPEN_SOURCE=500"
case "${host}" in
*linux*) unix98flags="-D_XOPEN_SOURCE=600" ;;
esac
])

dnl======================================================================
dnl AC_SENDS_FINISH - Things to be done at the very end for SENDS
dnl======================================================================
 
AC_DEFUN([AC_SENDS_FINISH],
[
  dnl ===================================================================
  dnl  Setup $architecture
  dnl ===================================================================
architecture=
case "${host}" in
*linux*) architecture="linux" ;;
*solaris*) architecture="solaris" ;;
esac
AC_SUBST(architecture)
  dnl ===================================================================
  dnl  Setup $syslibs
  dnl ===================================================================
syslibs=
case "${host}" in
*linux*) syslibs="-lrt" ;;
*solaris*) syslibs="-lrt" ;;
esac
AC_SUBST(syslibs)
  dnl ===================================================================
  dnl  Setup $netlib
  dnl ===================================================================
netlib=
case "${host}" in
*linux*) netlib="" ;;
*solaris*) netlib="-lnsl -lsocket -lresolv" ;;
esac
AC_SUBST(netlib)
  dnl ===================================================================
  dnl  Setup $readlinelibs
  dnl ===================================================================
readlinelibs=
case "${host}" in
*linux*) readlinelibs="-lreadline -ltermcap" ;;
*solaris*) readlinelibs="-lreadline -ltermcap" ;;
esac
AC_SUBST(readlinelibs)
  dnl ===================================================================
  dnl  Specify warning message level
  dnl ===================================================================
case "$SENDS_CC_FLAVOR" in
gnu)
  CFLAGS="${CFLAGS} -pipe -fPIC -Wall $posixflags $unix98flags"
  ;;
SunPRO)
  CFLAGS="${CFLAGS} -v -KPIC -xc99=none"
  ;;
esac
case "$SENDS_CXX_FLAVOR" in
gnu)
  CXXFLAGS="${CXXFLAGS} -pipe -fPIC -Wall -Woverloaded-virtual $posixflags $unix98flags"
  ;;
SunPRO)
  CXXFLAGS="${CXXFLAGS} -KPIC"
  ;;
esac
  dnl ===================================================================
  dnl  Specify optimization
  dnl ===================================================================
opt="-O3"
hiopt="-O6"
noopt="-O0"
AC_SUBST(opt)
AC_SUBST(hiopt)
AC_SUBST(noopt)
  dnl ===================================================================
  dnl  Writing config files
  dnl ===================================================================
  dnl AC_CONFIG_FILES(config/PConfig.h:config/PConfig.in)
])
